﻿using System;
using System.Windows.Forms;

using TestClient.HelloService;

namespace TestClient
{
    /// <summary>
    /// 메인 폼
    /// </summary>
    public partial class MainForm : Form
    {
        //////////////////////////////////////////////////////////////////////////////////////////////////// Constructor
        ////////////////////////////////////////////////////////////////////////////////////////// Public

        #region 생성자 - MainForm()

        /// <summary>
        /// 생성자
        /// </summary>
        public MainForm()
        {
            InitializeComponent();

            this.getHTTPDataButton.Click += getHTTPDataButton_Click;
            this.getTCPDataButton.Click  += getTCPDataButton_Click;
        }

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Method
        ////////////////////////////////////////////////////////////////////////////////////////// Private
        //////////////////////////////////////////////////////////////////////////////// Event

        #region HTTP 데이터 구하기 버튼 클릭시 처리하기 - getHTTPDataButton_Click(sender, e)

        /// <summary>
        /// HTTP 데이터 구하기 버튼 클릭시 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void getHTTPDataButton_Click(object sender, EventArgs e)
        {
            WriteMessage("START GET HTTP DATA");

            using(HelloServiceClient client = new HelloServiceClient("CustomBinding_IHelloService"))
            {
                string message = client.Hello("WCF");

                WriteMessage("RESULT : {0}", message);
            }

            WriteMessage("END GET HTTP DATA");
        }

        #endregion
        #region TCP 데이터 구하기 버튼 클릭시 처리하기 - getTCPDataButton_Click(sender, e)

        /// <summary>
        /// TCP 데이터 구하기 버튼 클릭시 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void getTCPDataButton_Click(object sender, EventArgs e)
        {
            WriteMessage("START GET TCP DATA");

            using(HelloServiceClient client = new HelloServiceClient("NetTcpBinding_IHelloService"))
            {
                string message = client.Hello("WCF");

                WriteMessage("RESULT : {0}", message);
            }

            WriteMessage("END GET TCP DATA");
        }

        #endregion

        //////////////////////////////////////////////////////////////////////////////// Function

        #region 메시지 쓰기 - WriteMessage(format, parameterArray)
 
        /// <summary>
        /// 메시지 쓰기
        /// </summary>
        /// <param name="format">포맷 문자열</param>
        /// <param name="parameterArray">매개 변수 배열</param>
        private void WriteMessage(string format, params object[] parameterArray)
        {
            string message;
 
            if(parameterArray.Length == 0)
            {
                message = format;
            }
            else
            {
                message = string.Format(format, parameterArray);
            }
 
            this.listBox.Items.Add(string.Format("[{0}] {1}", DateTime.Now.ToString("HH:mm:ss"), message));
 
            this.listBox.Update();
        }
 
        #endregion
    }
}